# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class RouteEntry(pulumi.CustomResource):
    cidr_block: pulumi.Output[str]
    """
    The destination CIDR block of the route entry to publish.
    """
    instance_id: pulumi.Output[str]
    """
    The ID of the CEN.
    """
    route_table_id: pulumi.Output[str]
    """
    The route table of the attached VBR or VPC.
    """
    def __init__(__self__, resource_name, opts=None, cidr_block=None, instance_id=None, route_table_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a CEN route entry resource. Cloud Enterprise Network (CEN) supports publishing and withdrawing route entries of attached networks. You can publish a route entry of an attached VPC or VBR to a CEN instance, then other attached networks can learn the route if there is no route conflict. You can withdraw a published route entry when CEN does not need it any more.

        For information about CEN route entries publishment and how to use it, see [Manage network routes](https://www.alibabacloud.com/help/doc-detail/86980.htm).

        ## Example Usage



        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_pulumi as pulumi

        hz = pulumi.providers.Alicloud("hz", region="cn-hangzhou")
        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-testAccCenRouteEntryConfig"
        default_zones = alicloud.get_zones(available_disk_category="cloud_efficiency",
            available_resource_creation="VSwitch")
        default_instance_types = alicloud.ecs.get_instance_types(availability_zone=default_zones.zones[0]["id"],
            cpu_core_count=1,
            memory_size=2)
        default_images = alicloud.ecs.get_images(most_recent=True,
            name_regex="^ubuntu_18.*64",
            owners="system")
        vpc = alicloud.vpc.Network("vpc", cidr_block="172.16.0.0/12")
        default_switch = alicloud.vpc.Switch("defaultSwitch",
            availability_zone=default_zones.zones[0]["id"],
            cidr_block="172.16.0.0/21",
            vpc_id=vpc.id)
        default_security_group = alicloud.ecs.SecurityGroup("defaultSecurityGroup",
            description="foo",
            vpc_id=vpc.id)
        default_instance = alicloud.ecs.Instance("defaultInstance",
            image_id=default_images.images[0]["id"],
            instance_name=name,
            instance_type=default_instance_types.instance_types[0]["id"],
            internet_charge_type="PayByTraffic",
            internet_max_bandwidth_out=5,
            security_groups=[default_security_group.id],
            system_disk_category="cloud_efficiency",
            vswitch_id=default_switch.id)
        cen = alicloud.cen.Instance("cen")
        attach = alicloud.cen.InstanceAttachment("attach",
            child_instance_id=vpc.id,
            child_instance_region_id="cn-hangzhou",
            instance_id=cen.id)
        route = alicloud.vpc.RouteEntry("route",
            destination_cidrblock="11.0.0.0/16",
            nexthop_id=default_instance.id,
            nexthop_type="Instance",
            route_table_id=vpc.route_table_id)
        foo = alicloud.cen.RouteEntry("foo",
            cidr_block=route.destination_cidrblock,
            instance_id=cen.id,
            route_table_id=vpc.route_table_id)
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cidr_block: The destination CIDR block of the route entry to publish.
        :param pulumi.Input[str] instance_id: The ID of the CEN.
        :param pulumi.Input[str] route_table_id: The route table of the attached VBR or VPC.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if cidr_block is None:
                raise TypeError("Missing required property 'cidr_block'")
            __props__['cidr_block'] = cidr_block
            if instance_id is None:
                raise TypeError("Missing required property 'instance_id'")
            __props__['instance_id'] = instance_id
            if route_table_id is None:
                raise TypeError("Missing required property 'route_table_id'")
            __props__['route_table_id'] = route_table_id
        super(RouteEntry, __self__).__init__(
            'alicloud:cen/routeEntry:RouteEntry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, cidr_block=None, instance_id=None, route_table_id=None):
        """
        Get an existing RouteEntry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cidr_block: The destination CIDR block of the route entry to publish.
        :param pulumi.Input[str] instance_id: The ID of the CEN.
        :param pulumi.Input[str] route_table_id: The route table of the attached VBR or VPC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["cidr_block"] = cidr_block
        __props__["instance_id"] = instance_id
        __props__["route_table_id"] = route_table_id
        return RouteEntry(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

